@@ -7,6 +7,9 @@
 #export DSOCKS_NAMESERVER="10.0.0.1"
 #export LOCALDOMAIN="int.example.com"
 
-LIBDSOCKS=/usr/local/lib/libdsocks.so.1.0
+# for MacOS X...
+#LIBDSOCKS=/usr/local/lib/libdsocks.dylib
+#DYLD_INSERT_LIBRARIES=$LIBDSOCKS DYLD_FORCE_FLAT_NAMESPACE=1 exec "$@"
 
-LD_PRELOAD=$LIBDSOCKS exec $*
+LIBDSOCKS=/usr/local/lib/libdsocks.so.1.0
+LD_PRELOAD=$LIBDSOCKS exec "$@"
